# -*- coding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2010-2013 OpenERP s.a. (<http://openerp.com>).
#    Copyright (C) 2013 initOS GmbH & Co. KG (<http://www.initos.com>).
#    Author Thomas Rehn <thomas.rehn at initos.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from openerp.osv import fields, osv


class ProductTemplate(osv.Model):
    _inherit = 'product.template'

    _columns = {
        'name': fields.char('Name', size=128, required=True, select=True),
        'description': fields.text('Description'),
        'description_purchase': fields.text('Purchase Description'),
        'description_sale': fields.text('Sale Description'),
    }

    def _remove_translations(self, cr, uid, ids=None, context=None):
        """Remove translations from name and description field"""

        # all fields for which we remove the translation
        fields_to_translate = [
            'name',
            'description',
            'description_purchase',
            'description_sale'
        ]
        for field in fields_to_translate:
            # copy German translations into product.template
            sql = """UPDATE product_template product
                        SET %(field)s =
                            COALESCE((
                                    SELECT value
                                      FROM ir_translation trans
                                     WHERE trans.lang = 'de_DE'
                                       AND trans.name =
                                           'product.template,%(field)s'
                                       AND trans.type = 'model'
                                       AND product.id = trans.res_id
                                     ), %(field)s)""" % {'field': field}
            cr.execute(sql)
            # delete German translations
            sql = """DELETE FROM ir_translation
                           WHERE lang = 'de_DE'
                             AND name = 'product.template,%(field)s'
                             AND type = 'model'""" % {'field': field}
            cr.execute(sql)
